:orphan:



.. _sphx_glr_tutorials:

Tutorials
================

This page is home to longer examples which incorporate multiple components of
:mod:`pyrolite` or provide examples of how to integrate these into your own workflows.

.. note:: This page is a work in progress. Feel free to request tutorials or examples
    with a feature request.



.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="In this tutorial we will illustrate some straightfoward formatting for your plots which will al...">

.. only:: html

 .. figure:: /tutorials/images/thumb/sphx_glr_plot_formatting_thumb.png

     :ref:`sphx_glr_tutorials_plot_formatting.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /tutorials/plot_formatting

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="Making the Logo">

.. only:: html

 .. figure:: /tutorials/images/thumb/sphx_glr_logo_thumb.png

     :ref:`sphx_glr_tutorials_logo.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /tutorials/logo

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="There are multiple ways you can acheive ternary heatmaps, but those based on the cartesian axes...">

.. only:: html

 .. figure:: /tutorials/images/thumb/sphx_glr_ternary_density_thumb.png

     :ref:`sphx_glr_tutorials_ternary_density.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /tutorials/ternary_density
.. raw:: html

    <div class="sphx-glr-clear"></div>



.. only:: html

 .. rst-class:: sphx-glr-signature

    `Gallery generated by Sphinx-Gallery <https://sphinx-gallery.github.io>`_
